@@ -2,7 +2,7 @@
 import base64
 import json
 from dataclasses import dataclass
-from typing import Callable, Dict, Any, AsyncIterator, Union
+from typing import Callable, Dict, Any, AsyncIterator, Union, Generator
 
 from google.api_core.exceptions import AlreadyExists, NotFound
 from google.cloud import pubsub_v1
@@ -22,7 +22,7 @@ class CloudPublisher(GoogleCloudPilotAPI):
             topic=topic_id,
         )
         try:
-            topic = self.client.create_topic(request={"name": topic_path})
+            topic = self.client.create_topic(name=topic_path)
         except AlreadyExists:
             if not exists_ok:
                 raise
@@ -30,7 +30,20 @@ class CloudPublisher(GoogleCloudPilotAPI):
         return topic
 
     async def get_topic(self, topic_id: str, project_id: str = None):
-        pass
+        topic_path = self.client.topic_path(
+            project=project_id or self.project_id,
+            topic=topic_id,
+        )
+        return self.client.get_topic(
+            topic=topic_path,
+        )
+
+    async def list_topics(self, project_id: str = None) -> Generator[types.Topic, None, None]:
+        project_path = self._project_path(project_id=project_id)
+        topics = self.client.list_topics(
+            project=project_path,
+        )
+        return topics
 
     async def publish(
             self,
@@ -72,8 +85,7 @@ class CloudSubscriber(GoogleCloudPilotAPI):
         all_subscriptions = self.client.list_subscriptions(
             project=f'projects/{project_id or self.project_id}',
         )
-        for subscription in all_subscriptions:
-            yield subscription
+        return all_subscriptions
 
     async def get_subscription(self, subscription_id: str, project_id: str = None) -> Subscription:
         subscription_path = self.client.subscription_path(
