@@ -1,4 +1,4 @@
-# https://cloud.google.com/source-repositories/docs/reference/rest
+# More Information: <https://cloud.google.com/source-repositories/docs/reference/rest>
 from typing import Dict, Any
 
 from gcp_pilot import exceptions
@@ -18,16 +18,13 @@ class SourceRepository(DiscoveryMixin, GoogleCloudPilotAPI):
             **kwargs,
         )
 
-    def _parent_path(self, project_id: str = None) -> str:
-        return f'projects/{project_id or self.project_id}'
-
     def _repo_path(self, repo: str, project_id: str = None) -> str:
-        parent_path = self._parent_path(project_id=project_id)
+        parent_path = self._project_path(project_id=project_id)
         return f'{parent_path}/repos/{repo}'
 
     async def list_repos(self, project_id: str = None) -> RepoType:
         params = dict(
-            name=self._parent_path(project_id=project_id),
+            name=self._project_path(project_id=project_id),
         )
         items = self._paginate(
             method=self.client.projects().repos().list,
@@ -44,7 +41,7 @@ class SourceRepository(DiscoveryMixin, GoogleCloudPilotAPI):
         )
 
     async def create_repo(self, repo_name: str, project_id: str = None, exists_ok: bool = True) -> RepoType:
-        parent = self._parent_path(project_id=project_id)
+        parent = self._project_path(project_id=project_id)
         repo_path = self._repo_path(repo=repo_name, project_id=project_id)
         try:
             return self._execute(
